pub enum Error {
MaxDepth,
InvalidHashBitLen,
ZeroPointers,
CidNotFound(String),
Dynamic(Box<dyn StdError>),
Other(String),
}Expand description
HAMT Error
Variants
MaxDepth
Maximum depth error
InvalidHashBitLen
Hash bits does not support greater than 8 bit width
ZeroPointers
This should be treated as a fatal error, must have at least one pointer in node
CidNotFound(String)
Cid not found in store error
Dynamic(Box<dyn StdError>)
Dynamic error for when the error needs to be forwarded as is.
Other(String)
Custom HAMT error